<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="text"/>
<xsl:param name="MID"/>  
<xsl:param name="SID"/>  
<xsl:param name="SECRET"/>

<xsl:variable name="URL" select="'url'"/>
<xsl:variable name="SIG" select="'sig'"/>
<xsl:variable name="INNER_REQUEST" select="'InnerRequest'"/>
<xsl:variable name="REQUEST" select="'Request'"/>
<xsl:variable name="RESPONSE" select="'Response'"/>
<xsl:variable name="PARAMS" select="'Params'"/>
<xsl:variable name="STRING" select="'string'"/>
<xsl:variable name="STRUCT" select="'struct'"/>
<xsl:variable name="ARRAY" select="'array'"/>
<xsl:variable name="IMG" select="'img'"/>

<xsl:variable name="FUNCTION" select="/Request/@function"/>  
<xsl:variable name="PARAMS2" select="document('requests.xml')//requests/request[(@function=$FUNCTION) or (@function='general')]"/>  


<xsl:include href="errors.xsl"/>

<xsl:template match="/response">

    <xsl:element name="{$RESPONSE}">
        <xsl:attribute name="class">messages</xsl:attribute>
        <xsl:attribute name="function">updateOutboxMessages</xsl:attribute>
        <xsl:element name="{$PARAMS}">

            <xsl:attribute name="id">
                <xsl:text>vk</xsl:text>
                <xsl:value-of select="$MID"/>
            </xsl:attribute>

            <xsl:element name="{$ARRAY}">
                <xsl:variable name="quantity" select="count(/response/messages/item)"/>
                <xsl:variable name="offset" select="offset"/> 
                <xsl:attribute name="name">messageList</xsl:attribute>
                <xsl:attribute name="from">
                    <xsl:if test="not(number($offset))">
                        <xsl:value-of select="'0'"/> 
                    </xsl:if>
                    <xsl:if test="number($offset)">
                        <xsl:value-of select="offset"/> 
                    </xsl:if>                 
                </xsl:attribute>
                <xsl:attribute name="to">
                    <xsl:if test="not(number($offset))">
                        <xsl:value-of select="number($quantity) - 1"/>
                    </xsl:if>
                    <xsl:if test="number($offset)">
                        <xsl:value-of select="number($offset) + number($quantity) - 1"/>
                    </xsl:if>                
                </xsl:attribute>
                <xsl:apply-templates select="/response/friends/*"/>

                <xsl:apply-templates select="/response/messages/item"/>
            </xsl:element> 

        </xsl:element> 
    </xsl:element> 
</xsl:template>


<xsl:template match="item">
    <xsl:if test="mid">
        <xsl:element name="{$STRUCT}">
            <xsl:attribute name="name">message</xsl:attribute>
            <xsl:attribute name="id">
                <xsl:text>vk</xsl:text>
            <xsl:value-of select="mid"/>
            </xsl:attribute>

            <xsl:element name="{$STRING}">
               <xsl:attribute name="name">SenderId</xsl:attribute>
                <xsl:text>vk</xsl:text>
               <xsl:value-of select="$MID"/>
            </xsl:element>

            <xsl:if test="uid">
                <xsl:if test="uid != '0'">
                	<xsl:variable name="current_uid" select="uid"/>
                    <xsl:element name="{$ARRAY}">
                        <xsl:attribute name="name">recipientList</xsl:attribute>
                        <xsl:attribute name="quantity">1</xsl:attribute>
                        <xsl:element name="{$STRUCT}">
                        <xsl:attribute name="name">recipient</xsl:attribute>
                        <xsl:element name="{$STRING}">
                           <xsl:attribute name="name">RecipientId</xsl:attribute>
                            <xsl:text>vk</xsl:text>
                           <xsl:value-of select="uid"/>
                        </xsl:element>
                        <xsl:element name="{$STRING}">
                           <xsl:attribute name="name">RecipientName</xsl:attribute>
                                <xsl:value-of select="//recipient/item[uid=$current_uid]/first_name"/>
                                <xsl:text> </xsl:text>
                                <xsl:value-of select="//recipient/item[uid=$current_uid]/last_name"/>
                        </xsl:element>
                        </xsl:element>
                    </xsl:element>
                </xsl:if>
            </xsl:if>

            <xsl:element name="{$STRING}">
                <xsl:attribute name="name">Time</xsl:attribute>
                <xsl:value-of select="date"/>
            </xsl:element>

            <xsl:element name="{$STRING}">
                <xsl:attribute name="name">Title</xsl:attribute>
                <xsl:value-of select="title"/>
            </xsl:element>

            <xsl:element name="{$STRING}">
                <xsl:attribute name="name">Text</xsl:attribute>
                <xsl:value-of select="body"/>
            </xsl:element>

            <xsl:element name="{$STRING}">
                <xsl:attribute name="name">Status</xsl:attribute>
                <xsl:value-of select="read_state"/>
            </xsl:element>

        </xsl:element>
    </xsl:if>
</xsl:template>
</xsl:stylesheet>
